# **Person** [![](https://gitee.com/tyoui/logo/raw/master/logo/photolog.png)][1]

## 关于中国人属性模块集合
[![](https://img.shields.io/badge/个人网站-jtyoui-yellow.com.svg)][1]
[![](https://img.shields.io/badge/Python-3.7-green.svg)]()
[![](https://img.shields.io/badge/BlogWeb-Tyoui-bule.svg)][1]
[![](https://img.shields.io/badge/Email-jtyoui@qq.com-red.svg)]()
[![](https://img.shields.io/badge/Person-人属性-black.svg)]()


### 安装
    pip install jtyoui

***
[1]: https://blog.jtyoui.com

### 百家姓
```python
from jtyoui.person import SurName,SurNameMessage
if __name__ == '__main__':
    print(SurName)
    print(SurNameMessage)
```

### 民族
```python
from jtyoui.person import NationsOther,Nations
if __name__ == '__main__':
    print(Nations)
    print(NationsOther)
```

***
[1]: https://blog.jtyoui.com